Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(492)

Unified Diff: telemetry/telemetry/internal/platform/tracing_agent/chrome_tracing_agent.py

Issue 2342303002: Reenable testTBM2ForSmoke & fix clock sync error on ref build of Chrome on Mac (Closed)
Patch Set: nits Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | telemetry/telemetry/web_perf/timeline_based_page_test_unittest.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: telemetry/telemetry/internal/platform/tracing_agent/chrome_tracing_agent.py
diff --git a/telemetry/telemetry/internal/platform/tracing_agent/chrome_tracing_agent.py b/telemetry/telemetry/internal/platform/tracing_agent/chrome_tracing_agent.py
index fd6e6607516a2b9970f2c3099a028c1e7781ba9c..ccedeba2ad3919fae09a93a9e842f722e6d4ee2a 100644
--- a/telemetry/telemetry/internal/platform/tracing_agent/chrome_tracing_agent.py
+++ b/telemetry/telemetry/internal/platform/tracing_agent/chrome_tracing_agent.py
@@ -178,11 +178,17 @@ class ChromeTracingAgent(tracing_agent.TracingAgent):
for client in devtools_clients:
version = client.GetChromeBranchNumber()
break
- if version and int(version) >= 2661:
+ logging.info('Chrome version: %s', version)
+ # Note, we aren't sure whether 2744 is the correct cut-off point which
+ # Chrome will support clock sync marker, however we verified that 2743 does
+ # not support clock sync (catapult/issues/2804) hence we use it here.
+ # On the next update of Chrome ref build, if testTBM2ForSmoke still fails,
+ # the cut-off branch number will need to be bumped up again.
+ if version and int(version) > 2743:
self._RecordClockSyncMarkerDevTools(
sync_id, record_controller_clock_sync_marker_callback,
devtools_clients)
- else: # TODO(rnephew): Remove once chrome stable is past branch 2661.
+ else: # TODO(rnephew): Remove once chrome stable is past branch 2743.
self._RecordClockSyncMarkerAsyncEvent(
sync_id, record_controller_clock_sync_marker_callback)
« no previous file with comments | « no previous file | telemetry/telemetry/web_perf/timeline_based_page_test_unittest.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698